<?php
/**
 * Ce fichier contient les fonctions de service nécessitées par le plugin Cache Factory.
 */
if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

/**
 * Renvoie la configuration spécifique des caches gérés par Mashup Factory pour les targets (fichiers contenant les
 * données du mashup).
 *
 * @param string $plugin Identifiant qui permet de distinguer le module appelant qui peut-être un plugin comme le noiZetier ou
 *                       un script. Pour un plugin, le plus pertinent est d'utiliser le préfixe.
 *
 * @return array<string, mixed> Tableau de la configuration brute du plugin Taxonomie.
 */
function ezmashup_cache_configurer(string $plugin) : array {
	// Initialisation du tableau de configuration avec les valeurs par défaut du plugin Mashup Factory.
	// -- le codage est omis car il est déduit de l'extension.
	$configuration = [
		'target' => [
			'racine'          => '_DIR_ETC',
			'sous_dossier'    => true,
			'nom_prefixe'     => 'target',
			'nom_obligatoire' => ['id_target'],
			'nom_facultatif'  => [],
			'extension'       => '.json',
			'securisation'    => false,
			'serialisation'   => false,
			'codage'          => 'json',
			'separateur'      => '-',
			'conservation'    => 0,
			'administration'  => false
		],
		'config' => [
			'racine'          => '_DIR_ETC',
			'sous_dossier'    => true,
			'nom_prefixe'     => 'config',
			'nom_obligatoire' => [],
			'nom_facultatif'  => [],
			'extension'       => '.yaml',
			'securisation'    => false,
			'serialisation'   => false,
			'codage'          => 'yaml',
			'separateur'      => '',
			'conservation'    => 0,
			'administration'  => false
		],
		'source_json' => [
			'racine'          => '_DIR_ETC',
			'sous_dossier'    => true,
			'nom_prefixe'     => 'source',
			'nom_obligatoire' => ['id_source'],
			'nom_facultatif'  => [],
			'extension'       => '.json',
			'securisation'    => false,
			'serialisation'   => false,
			'codage'          => 'json',
			'separateur'      => '-',
			'conservation'    => 0,
			'administration'  => false
		],
	];

	// On recopie la config de la source json pour le xml et le csv car seule l'extension change
	$configuration['source_xml'] = $configuration['source_json'];
	$configuration['source_xml']['extension'] = '.xml';
	$configuration['source_xml']['codage'] = 'xml';
	$configuration['source_csv'] = $configuration['source_json'];
	$configuration['source_csv']['extension'] = '.csv';
	$configuration['source_csv']['codage'] = 'csv';

	return $configuration;
}
